--******************************************************************************/
--******************************************************************************/
--*                                                                            */
--* Trigger: COPIA_REF_ROD                                                     */
--* Tabela : PRODUTO                                                           */
--*                                                                            */
--* Criao:                                                                   */
--* 17/12/2010 - William Azevedo de Paula                                      */
--*                                                                            */ 
--* Descrio: copia dados da tabela PRODUTO para a tabela REFBIBPROD,         */      
--* e altera a data de ltiama atualizao (DTULTATU) da mesma, para que       */ 
--* ela pudesse ser utilizada em cache no lugar da tabela PRODUTO;             */
--******************************************************************************/
--******************************************************************************/
CREATE OR REPLACE TRIGGER COPIA_REF_PROD
AFTER INSERT OR UPDATE
ON PRODUTO FOR EACH ROW
DECLARE
   V_CDPRODUTO VARCHAR2(10);
BEGIN
   
   BEGIN
      SELECT CDPRODUTO 
      INTO V_CDPRODUTO 
      FROM REFBIBPROD 
      WHERE CDPRODUTO = :NEW.CDPRODUTO;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_CDPRODUTO := NULL;
   END;
   
   IF INSERTING THEN
      IF V_CDPRODUTO IS NULL THEN
         IF NOT(:NEW.DSREFBIBPROD IS NULL) THEN
            INSERT INTO REFBIBPROD(CDPRODUTO,DSREFBIBPROD,DTULTATU)
                        VALUES(:NEW.CDPRODUTO,:NEW.DSREFBIBPROD,SYSDATE);                      
         END IF;
      ELSE
         IF NOT(:NEW.DSREFBIBPROD IS NULL) THEN
            UPDATE REFBIBPROD SET DSREFBIBPROD = :NEW.DSREFBIBPROD,DTULTATU = SYSDATE WHERE CDPRODUTO = :NEW.CDPRODUTO;
         ELSE
            DELETE FROM REFBIBPROD WHERE CDPRODUTO = :NEW.CDPRODUTO;
         END IF;
      END IF;
   END IF;
   IF UPDATING THEN
      IF (NVL(:OLD.DSREFBIBPROD,0) <> NVL(:NEW.DSREFBIBPROD,0)) THEN
         IF NOT (V_CDPRODUTO IS NULL) THEN
            IF NOT(:NEW.DSREFBIBPROD IS NULL) THEN
               UPDATE REFBIBPROD SET DSREFBIBPROD = :NEW.DSREFBIBPROD,DTULTATU = SYSDATE WHERE CDPRODUTO = :NEW.CDPRODUTO;
            ELSE
               DELETE FROM REFBIBPROD WHERE CDPRODUTO = :NEW.CDPRODUTO;
            END IF;
         ELSE 
            IF NOT(:NEW.DSREFBIBPROD IS NULL) THEN
               INSERT INTO REFBIBPROD(CDPRODUTO,DSREFBIBPROD,DTULTATU)
                         VALUES(:NEW.CDPRODUTO,:NEW.DSREFBIBPROD,SYSDATE); 
            END IF;
         END IF ;   
      END IF;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('COPIA_REF_PROD','4.11.134'); END;
/
