function LoginService(requestDataSourceEngine, restEngine, ScreenService, LibUtilities, LibLoginController, WidgetsMetaData, localStorageEngine, MessageService) {
    
    let userData = {
        id: '',
        name: ''
    };
    
    let self = this;
    
    this.setUserData = function (userId, userName){
        userData.id = userId;
        userData.name = userName;
    };
    
    this.newRow = function(){
        var event;
		if (this.beforeNewRow) {
			event = this.beforeNewRow();
		}
		if (!event || !event.isDefaultPrevented()) {

			var _oldValuesToRepeat = this.getRepeatOnNewValues();
			var row = {};
			var bkpRow = this.currentRow;
			if (this.dataSource) {
				this.dataSource.newRow();
				row = this.dataSource.data[this.dataSource.data.length - 1];
				if(bkpRow){
				    Object.assign(row, bkpRow);
				}
			}
			this.setCurrentRow(row);
			this.applyDefaultValue();
			Util.extend(this.currentRow, _oldValuesToRepeat);
			this.edit();
			if (this.onNewRow) {
				this.onNewRow();
			}
		}
    };
    
    this.logoutExpiredSession = function (afterLogin) {
        localStorageEngine.setLocalVar('LOGIN_EXPIRED_SESSION', false);
        var message = afterLogin ? 'ERR_EXPIRED_SESSION_LOGIN' : 'ERR_ATTEMPT_END';
        MessageService.getMessageByCode('lib#' + message).then(function(loadingMessage) {
            ScreenService.changeLoadingMessage(ScreenService.i18n(loadingMessage));
            ScreenService.showLoader();
            Util.doAsync(libLogout, 5000);
        });
    };
    
    const libLogout = function(){
        LibLoginController.logout();
        ScreenService.hideLoader();
        ScreenService.restoreDefaultLoadingMessage();
    };
    
    /* global Configuration */
    (function setAuthenticationContainer(){
        LibUtilities.authenticationContainer = "product#Login";
        
        WidgetsMetaData.getExpiredSession = function() {
            return {
                "name": "EXPIRED_SESSION",
                "label": "Sessão Expirada",
                "isVisible": true,
                "showDescriptionOrder": false,
                "showAsModal": true,
                "template": "widget/form.html",
                "tekLibExpiredSession": true,
                "currentRow": {
                    "OPERATOR_ECOMMERCE": `${userData.id} - ${userData.name}`
                },
                "newRow": this.newRow,
                "actions": [
                    {
                        "name": "CONFIRM",
                        "label": "Confirmar",
                        "showAsAction": "never",
                        "events": [
                            {
                                "name": "ActionEvent",
                                "code": "LibLoginController.expiredSessionActionEventConfirm(args)"
                            }
                        ]
                    },
                    {
                        "name": "CANCEL",
                        "label": "Sair",
                        "showAsAction": "back",
                        "events": [
                            {
                                "name": "ActionEvent",
                                "code": "LibLoginController.expiredSessionActionEventCancel()"
                            }
                        ]
                    }
                ],
                "events": [],
                "dataSource": [],
                "fields": [
                    {
                        "name": "OPERATOR",
                        "label": "Usuário",
                        "template": "field/text-edit.html",
                        "class": 12,
                        "readOnly": true,
                        "isVisible": false,
                        "showOnList": false,
                        "showOnForm": false
                    },
                    {
                        "name": "OPERATOR_ECOMMERCE",
                        "label": "Usuário",
                        "template": "field/text-edit.html",
                        "class": 12,
                        "readOnly": true,
                        "isVisible": true,
                        "showOnList": true,
                        "showOnForm": true,
                        "applyDefaultValue": function(){}
                    },
                    {
                        "name": "PASSWORD",
                        "label": "Senha",
                        "template": "field/password.html",
                        "class": 12,
                        "focused": true,
                        "validations":{
                            required: true
                        },
                        "isVisible": true,
                        "showOnList": true,
                        "showOnForm": true,
                        "events":[
                            {
                                "name": "FieldOnKeyup",
                                "code": "LibLoginController.expiredSessionFieldOnKeyupPassword(args)"
                            }
                        ]
                    }
                ]
            };
        }.bind(this);
        
        LibLoginController.expiredSessionActionEventConfirm = function( args ){
            var expiredSessionWidget = args.owner.widget ? args.owner.widget : args.owner.field.widget;
            if(expiredSessionWidget.isValid()) {
                var password = expiredSessionWidget.currentRow.PASSWORD;
                ScreenService.showLoader();
                validateUser(userData.id, password)
                    .then(function(response) {
                        ScreenService.hideLoader();
                        let userValidation = response && response.dataset && response.dataset.userValidation ? response.dataset.userValidation : {};
                        if(userValidation.IS_VALID){
                            localStorageEngine.setLocalVar('LOGIN_EXPIRED_SESSION', false);
                            ScreenService.closePopup();
                        } else {
                            var params = {attempts: ++expiredSessionWidget.attempts};
                            MessageService.showMessageByCode('lib#ERR_ATTEMPT_PARTIAL', params, {type: 'ERROR'});
                            if (expiredSessionWidget.attempts >= 3) {
                                self.logoutExpiredSession();
                            }
                        }
                    }).catch(function(error) {
                        ScreenService.hideLoader();
                        if(error.data && error.data.ERROR) {
                            MessageService.showMessageByCode(error.data.ERROR);
                        } else {
                            MessageService.showMessageByCode("ERR_UNEXPECTED_ERROR");
                        }
                    });
            }
        };
        
    }.bind(this))();
    
    this.requestFilter = function(route, filter) {
        return requestDataSourceEngine.getDataSource(route, filter, 1, undefined, undefined, undefined, 120000);
    };
    
    this.requestRow = function(route, row) {
        return restEngine.post(
            route, 
            {
                'requestType': 'Row',
                'row': row
            }
        );
    };
    
    function validateUser(cdOperador, password){
        return restEngine.post(
            '/validateUser', 
            {
                'requestType': 'Row',
                'row': {
                    'USER'    : cdOperador,
                    'PASSWORD': password
                }
            }
        );
    }
}

Configuration(function(ContextRegister) {
    ContextRegister.register('LoginService', LoginService);
});
